@@ -4,11 +4,11 @@
  *    http://www.robobunny.com/projects/asciiquarium/
  *
  * Ported to KDE by Maksim Orlovich <maksim@kde.org> and
- * Michael Pyne <michael.pyne@kdemail.net>.
+ * Michael Pyne <mpyne@kde.org>.
  *
  * Copyright (c) 2003 Kirk Baucom     <kbaucom@schizoid.com>
  * Copyright (c) 2005 Maksim Orlovich <maksim@kde.org>
- * Copyright (c) 2005, 2008 Michael Pyne <michael.pyne@kdemail.net>
+ * Copyright (c) 2005, 2008 Michael Pyne <mpyne@kde.org>
  *
  * ASCII Art was mostly created by Joan Stark:
  *    http://www.geocities.com/SoHo/7373/
@@ -1161,7 +1161,7 @@ void AASaver::addNessie(Screen* screen)
 "                                             __{}{}{}{}?/   o  \\\n"
 "             _{}{}{}{}{}{}{}{}{}{}?_{}{}{}?/    \\{}{}?/     ____ >\n"
 "   _{}{}{}?/   \\{}{}{}{}_{}{}{}{}/   \\{}{}|  __  |{}?|     |\n"
-"  | \\{}{}?|     |{}{}?/   \\{}{}?|     |{}?|  ||  |{}?|     |\n",
+"  | \\{}{}?|     |{}{}?/   \\{}{}?|     |{}?|  ||  |{}?|     |",
 
 "                                                          ____\n"
 "                                  __{}{}{}{}{}{}{}{}{}{}/   o  \\\n"
@@ -1274,7 +1274,7 @@ AASaverInterface::~AASaverInterface()
 
 KAboutData *AASaverInterface::aboutData()
 {
-    return new KAboutData("kdeasciiquarium.kss", "kdeasciiquarium", ki18n("KDE Asciiquarium"), "0.4.1",
+    return new KAboutData("kdeasciiquarium.kss", "kdeasciiquarium", ki18n("KDE Asciiquarium"), "0.4.2",
         ki18n("KDE Asciiquarium"));
 }
 
