@@ -48,6 +48,9 @@
 #include "slideshow.h"
 #include "slideshow.moc"
 
+#ifdef HAVE_KEXIV2
+#include <libkexiv2/kexiv2.h>
+#endif
 
 #define SLIDESHOW_VERSION "2.3.0"
 static const char version[] = SLIDESHOW_VERSION;
@@ -106,7 +109,7 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   mEffectRunning = false;
 
   mTimer.setSingleShot(true);
-  connect(&mTimer, SIGNAL(timeout()), SLOT(slotTimeout()));
+  connect(&mTimer, SIGNAL(timeout()), SLOT(update()));
   mTimer.start(10);
 
   QDesktopWidget *d = QApplication::desktop();
@@ -703,13 +706,6 @@ void kSlideShowSaver::restart()
 }
 
 
-//-----------------------------------------------------------------------------
-void kSlideShowSaver::slotTimeout()
-{
-  update();
-}
-
-
 //-----------------------------------------------------------------------------
 void kSlideShowSaver::paintEvent(QPaintEvent *)
 {
@@ -885,6 +881,11 @@ nexttry:
   }
   mFileIdx++;
 
+#ifdef HAVE_KEXIV2
+  KExiv2Iface::KExiv2 exiv(fname);
+  exiv.rotateExifQImage(mImage, exiv.getImageOrientation());
+#endif
+
   mImageName = QFileInfo(fname).baseName();
 }
 
